from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSCHPreUFFArchives.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSDArchives_pb2 as TSDArchives__pb2
from . import TSSArchives_pb2 as TSSArchives__pb2
from . import TSCHArchives_Common_pb2 as TSCHArchives__Common__pb2
from . import TSCH3DArchives_pb2 as TSCH3DArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSCHPreUFFArchives.proto',
  package='TSCH.PreUFF',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x18TSCHPreUFFArchives.proto\x12\x0bTSCH.PreUFF\x1a\x11TSPMessages.proto\x1a\x11TSKArchives.proto\x1a\x11TSDArchives.proto\x1a\x11TSSArchives.proto\x1a\x19TSCHArchives_Common.proto\x1a\x14TSCH3DArchives.proto\"\xcc\x07\n\x10\x43hartInfoArchive\x12#\n\x05super\x18\x01 \x02(\x0b\x32\x14.TSD.DrawableArchive\x12\x33\n\x0b\x63hart_model\x18\x02 \x02(\x0b\x32\x1e.TSCH.PreUFF.ChartModelArchive\x12\x1d\n\x05style\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12#\n\nchart_type\x18\x04 \x02(\x0e\x32\x0f.TSCH.ChartType\x12\x35\n\x0clegend_model\x18\x05 \x01(\x0b\x32\x1f.TSCH.PreUFF.LegendModelArchive\x12,\n\x11inner_chart_frame\x18\x06 \x02(\x0b\x32\x11.TSCH.RectArchive\x12)\n\x11value_axis_styles\x18\x07 \x03(\x0b\x32\x0e.TSP.Reference\x12,\n\x14\x63\x61tegory_axis_styles\x18\x08 \x03(\x0b\x32\x0e.TSP.Reference\x12,\n\x14value_axis_nonstyles\x18\t \x03(\x0b\x32\x0e.TSP.Reference\x12/\n\x17\x63\x61tegory_axis_nonstyles\x18\n \x03(\x0b\x32\x0e.TSP.Reference\x12+\n\x13series_theme_styles\x18\x0b \x03(\x0b\x32\x0e.TSP.Reference\x12\x38\n\x15series_private_styles\x18\x0c \x01(\x0b\x32\x19.TSP.SparseReferenceArray\x12\x34\n\x11series_non_styles\x18\r \x01(\x0b\x32\x19.TSP.SparseReferenceArray\x12!\n\tnon_style\x18\x0e \x01(\x0b\x32\x0e.TSP.Reference\x12 \n\x08mediator\x18\x0f \x01(\x0b\x32\x0e.TSP.Reference\x12&\n\x12\x63\x64\x65_preview_origin\x18\x10 \x01(\x0b\x32\n.TSP.Point\x12*\n\x12\x63hart_style_preset\x18\x11 \x01(\x0b\x32\x0e.TSP.Reference\x12(\n\x10paragraph_styles\x18\x12 \x03(\x0b\x32\x0e.TSP.Reference\x12\"\n\x1alast_row_sected_in_the_cde\x18\x13 \x01(\x05\x12%\n\x1dlast_column_sected_in_the_cde\x18\x14 \x01(\x05\x12 \n\x18\x63hart_style_preset_index\x18\x15 \x01(\x05\x12\x30\n(needs_calc_engine_deferred_import_action\x18\x16 \x01(\x08\"\x96\x01\n\x12LegendModelArchive\x12\x1c\n\x04info\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12 \n\x05\x66rame\x18\x02 \x02(\x0b\x32\x11.TSCH.RectArchive\x12\x1d\n\x05style\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\x12!\n\tnon_style\x18\x04 \x02(\x0b\x32\x0e.TSP.Reference\"\xcd\x01\n\x11\x43hartModelArchive\x12\x1c\n\x04info\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1c\n\x04grid\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x14\n\x0cseries_types\x18\x03 \x03(\r\x12\x16\n\x0escatter_format\x18\x04 \x01(\r\x12\x32\n\x0binline_grid\x18\x05 \x01(\x0b\x32\x1d.TSCH.PreUFF.ChartGridArchive\x12\x1a\n\x12multidataset_index\x18\x06 \x01(\r\"\xb1\x01\n\x10\x43hartGridArchive\x12\x11\n\tdirection\x18\x01 \x02(\x05\x12\x10\n\x08row_name\x18\x02 \x03(\t\x12\x13\n\x0b\x63olumn_name\x18\x03 \x03(\t\x12\x39\n\tvalue_row\x18\x04 \x03(\x0b\x32&.TSCH.PreUFF.ChartGridArchive.ValueRow\x12\r\n\x05\x64irty\x18\x06 \x02(\x08\x1a\x19\n\x08ValueRow\x12\r\n\x05value\x18\x01 \x03(\x01\"\xac\x06\n\x19\x43hartsNumberFormatArchive\x12)\n\nvalue_type\x18\x01 \x02(\x0e\x32\x15.TSCH.NumberValueType\x12\x15\n\rformat_string\x18\x02 \x01(\t\x12\x16\n\x0e\x64\x65\x63imal_places\x18\x03 \x02(\r\x12\x15\n\rcurrency_code\x18\x04 \x01(\t\x12\x31\n\x0enegative_style\x18\x05 \x02(\x0e\x32\x19.TSCH.NegativeNumberStyle\x12 \n\x18show_thousands_separator\x18\x06 \x02(\x08\x12\x31\n\x11\x66raction_accuracy\x18\x07 \x02(\x0e\x32\x16.TSCH.FractionAccuracy\x12\x15\n\rsuffix_string\x18\x08 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\t \x02(\r\x12\x13\n\x0b\x62\x61se_places\x18\n \x02(\r\x12\x1b\n\x13\x62\x61se_use_minus_sign\x18\x0b \x02(\x08\x12\x1c\n\x14use_accounting_style\x18\x0c \x02(\x08\x12\x11\n\tis_custom\x18\r \x02(\x08\x12\x14\n\x0cscale_factor\x18\x0e \x02(\x01\x12\x1c\n\x14interstitial_strings\x18\x0f \x03(\t\x12<\n%interstitial_string_insertion_indexes\x18\x10 \x02(\x0b\x32\r.TSP.IndexSet\x12\x32\n*index_from_right_of_last_digit_placeholder\x18\x11 \x02(\r\x12\x16\n\x0eis_text_format\x18\x12 \x02(\x08\x12\x1d\n\x15minimum_integer_width\x18\x13 \x02(\r\x12\x15\n\rdecimal_width\x18\x14 \x02(\r\x12\x36\n.number_of_non_space_integer_placeholder_digits\x18\x15 \x02(\r\x12\x36\n.number_of_non_space_decimal_placeholder_digits\x18\x16 \x02(\r\x12\x13\n\x0b\x66ormat_name\x18\x17 \x01(\t\x12\x15\n\rprefix_string\x18\x18 \x01(\t\"\xf5\x12\n\x11\x43hartStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12<\n\"tschchartinfodefaultbackgroundfill\x18\n \x01(\x0b\x32\x10.TSD.FillArchive\x12@\n$tschchartinfodefaultbackgroundstroke\x18\x0b \x01(\x0b\x32\x12.TSD.StrokeArchive\x12@\n&tschchartinfodefaultgridbackgroundfill\x18\x0c \x01(\x0b\x32\x10.TSD.FillArchive\x12\'\n\x1ftschchartinfodefaultintersetgap\x18\r \x01(\x02\x12\'\n\x1ftschchartinfodefaultinterbargap\x18\x0e \x01(\x02\x12&\n\x1etschchartinfodefaultshowborder\x18\x0f \x01(\x08\x12<\n tschchartinfodefaultborderstroke\x18\x10 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x32\n\x1etschchartinfodefaulttitlecolor\x18\x12 \x01(\x0b\x32\n.TSP.Color\x12\x31\n)tschchartinfodefaultgridbackgroundopacity\x18\x13 \x01(\x02\x12)\n!tschchartinfodefaultcombinelayers\x18\x14 \x01(\x08\x12<\n tschchartinfodefaultbordershadow\x18\x15 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12)\n!tschchartinfodefaultborderopacity\x18\x16 \x01(\x02\x12\x34\n,tschchartinfodefaulttitleparagraphstyleindex\x18\x17 \x01(\x05\x12\x36\n.tschchartinfodefaultdeprecatedmasterfontfamily\x18\x18 \x01(\t\x12\x39\n1tschchartinfodefaultdeprecatedmasterfontnamedsize\x18\x19 \x01(\x05\x12J\nBtschchartinfodefaultdeprecatedtrendlineequationparagraphstyleindex\x18\x1e \x01(\x05\x12J\nBtschchartinfodefaultdeprecatedtrendlinersquaredparagraphstyleindex\x18\x1f \x01(\x05\x12Q\n5tschchartinfodefaultdeprecatedtrendlineequationshadow\x18  \x01(\x0b\x32\x12.TSD.ShadowArchive\x12Q\n5tschchartinfodefaultdeprecatedtrendlinersquaredshadow\x18! \x01(\x0b\x32\x12.TSD.ShadowArchive\x12>\n6tschchartinfodefaultdeprecatedtrendlineequationopacity\x18\" \x01(\x02\x12>\n6tschchartinfodefaultdeprecatedtrendlinersquaredopacity\x18# \x01(\x02\x12?\n\"tschchartinfobardeprecated3dshadow\x18\xb4\x02 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x42\n%tschchartinfocolumndeprecated3dshadow\x18\xb5\x02 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12@\n#tschchartinfolinedeprecated3dshadow\x18\xb6\x02 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12@\n#tschchartinfoareadeprecated3dshadow\x18\xb7\x02 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12?\n\"tschchartinfopiedeprecated3dshadow\x18\xb8\x02 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12S\n%tschchartinfodefault3dlightingpackage\x18\xb9\x02 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12R\n$tschchartinfocolumn3dlightingpackage\x18\xba\x02 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12O\n!tschchartinfobar3dlightingpackage\x18\xbb\x02 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12P\n\"tschchartinfoline3dlightingpackage\x18\xbc\x02 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12P\n\"tschchartinfoarea3dlightingpackage\x18\xbd\x02 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12O\n!tschchartinfopie3dlightingpackage\x18\xbe\x02 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12\x33\n*tschchartinfodefaultdeprecated3dbeveledges\x18\xc6\x02 \x01(\x08\x12/\n&tschchartinfopiedeprecated3dbeveledges\x18\xc7\x02 \x01(\x08\x12/\n&tschchartinfobardeprecated3dbeveledges\x18\xc8\x02 \x01(\x08\x12\x32\n)tschchartinfocolumndeprecated3dbeveledges\x18\xc9\x02 \x01(\x08\x12\x31\n(tschchartinfodefaultdeprecated3dbarshape\x18\xca\x02 \x01(\x05\x12+\n\"tschchartinfodefault3dchartopacity\x18\xcf\x02 \x01(\x02\"\xf9\x0b\n\x14\x43hartNonStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12!\n\x19tschchartinfodefaulttitle\x18\n \x01(\t\x12&\n\x1etschchartinfodefaultshowlegend\x18\x0b \x01(\x08\x12)\n!tschchartinfodefaultpiestartangle\x18\x0c \x01(\x02\x12%\n\x1dtschchartinfodefaultshowtitle\x18\r \x01(\x08\x12>\n6tschchartinfodefaultdeprecatedagainmasterfontnamedsize\x18\x19 \x01(\x05\x12\x43\n\x1etschchartinfodefault3drotation\x18\xac\x02 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12@\n\x1btschchartinfodefault3dscale\x18\xad\x02 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12?\n\x1atschchartinfocolumn3dscale\x18\xae\x02 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12<\n\x17tschchartinfobar3dscale\x18\xaf\x02 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12=\n\x18tschchartinfoline3dscale\x18\xb0\x02 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12=\n\x18tschchartinfoarea3dscale\x18\xb1\x02 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12<\n\x17tschchartinfopie3dscale\x18\xb2\x02 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12\x43\n\x1etschchartinfodefault3dviewport\x18\xb9\x02 \x01(\x0b\x32\x1a.TSCH.Chart3DVectorArchive\x12]\n/tschchartinfodefaultdeprecated3dlightingpackage\x18\xc0\x02 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12\\\n.tschchartinfocolumndeprecated3dlightingpackage\x18\xc1\x02 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12Y\n+tschchartinfobardeprecated3dlightingpackage\x18\xc2\x02 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12Z\n,tschchartinfolinedeprecated3dlightingpackage\x18\xc3\x02 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12Z\n,tschchartinfoareadeprecated3dlightingpackage\x18\xc4\x02 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12Y\n+tschchartinfopiedeprecated3dlightingpackage\x18\xc5\x02 \x01(\x0b\x32#.TSCH.Chart3DLightingPackageArchive\x12+\n\"tschchartinfodefaultskiphiddendata\x18\xc6\x02 \x01(\x08\x12)\n tschchartinfodefault3dbeveledges\x18\xc7\x02 \x01(\x08\x12\'\n\x1etschchartinfodefault3dbarshape\x18\xd0\x02 \x01(\x05\x12/\n&tschchartinfodefault3dintersetdepthgap\x18\xcb\x02 \x01(\x02\"\xbf\x02\n\x12LegendStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12\x34\n\x1atschlegendmodeldefaultfill\x18\n \x01(\x0b\x32\x10.TSD.FillArchive\x12\x38\n\x1ctschlegendmodeldefaultstroke\x18\x0b \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x38\n\x1ctschlegendmodeldefaultshadow\x18\x0e \x01(\x0b\x32\x12.TSD.ShadowArchive\x12%\n\x1dtschlegendmodeldefaultopacity\x18\x0f \x01(\x02\x12\x36\n.tschlegendmodeldefaultlabelparagraphstyleindex\x18\x10 \x01(\x05\"9\n\x15LegendNonStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\"\xad\x11\n\x15\x43hartAxisStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12,\n$tschchartaxisvalueshowmajorgridlines\x18\n \x01(\x08\x12,\n$tschchartaxisvalueshowminorgridlines\x18\x0b \x01(\x08\x12\x41\n%tschchartaxisvaluemajorgridlinestroke\x18\x0c \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x41\n%tschchartaxisvalueminorgridlinestroke\x18\r \x01(\x0b\x32\x12.TSD.StrokeArchive\x12*\n\"tschchartaxisvaluetickmarklocation\x18\x0e \x01(\x05\x12,\n$tschchartaxisvalueshowmajortickmarks\x18\x0f \x01(\x08\x12,\n$tschchartaxisvalueshowminortickmarks\x18\x10 \x01(\x08\x12+\n#tschchartaxisvaluelabelsorientation\x18\x11 \x01(\x02\x12*\n\"tschchartaxisvalueshowminimumlabel\x18\x12 \x01(\x08\x12\x41\n%tschchartaxisvaluemajorgridlineshadow\x18\x15 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x41\n%tschchartaxisvalueminorgridlineshadow\x18\x16 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12.\n&tschchartaxisvaluemajorgridlineopacity\x18\x17 \x01(\x02\x12.\n&tschchartaxisvalueminorgridlineopacity\x18\x18 \x01(\x02\x12\"\n\x1atschchartaxisvalueshowaxis\x18\x19 \x01(\x08\x12/\n\'tschchartaxiscategoryshowmajorgridlines\x18\x32 \x01(\x08\x12/\n\'tschchartaxiscategoryshowminorgridlines\x18\x33 \x01(\x08\x12\x44\n(tschchartaxiscategorymajorgridlinestroke\x18\x34 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x44\n(tschchartaxiscategoryminorgridlinestroke\x18\x35 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12-\n%tschchartaxiscategorytickmarklocation\x18\x36 \x01(\x05\x12/\n\'tschchartaxiscategoryshowmajortickmarks\x18\x37 \x01(\x08\x12/\n\'tschchartaxiscategoryshowminortickmarks\x18\x38 \x01(\x08\x12.\n&tschchartaxiscategorylabelsorientation\x18\x39 \x01(\x02\x12.\n&tschchartaxiscategoryhorizontalspacing\x18: \x01(\x05\x12,\n$tschchartaxiscategoryverticalspacing\x18; \x01(\x05\x12*\n\"tschchartaxiscategoryshowlastlabel\x18< \x01(\x08\x12\x44\n(tschchartaxiscategorymajorgridlineshadow\x18? \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x44\n(tschchartaxiscategoryminorgridlineshadow\x18@ \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x31\n)tschchartaxiscategorymajorgridlineopacity\x18\x41 \x01(\x02\x12\x31\n)tschchartaxiscategoryminorgridlineopacity\x18\x42 \x01(\x02\x12%\n\x1dtschchartaxiscategoryshowaxis\x18\x43 \x01(\x08\x12-\n%tschchartaxisdefaultlabelsorientation\x18\x66 \x01(\x02\x12\x34\n,tschchartaxisdefaulttitleparagraphstyleindex\x18n \x01(\x05\x12\x34\n,tschchartaxisdefaultlabelparagraphstyleindex\x18o \x01(\x05\x12\x32\n*tschchartaxisvaluetitleparagraphstyleindex\x18p \x01(\x05\x12\x32\n*tschchartaxisvaluelabelparagraphstyleindex\x18q \x01(\x05\x12\x35\n-tschchartaxiscategorytitleparagraphstyleindex\x18r \x01(\x05\x12\x35\n-tschchartaxiscategorylabelparagraphstyleindex\x18s \x01(\x05\x12?\n\"tschchartaxisvalue3dgridlinestroke\x18\xcb\x02 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x42\n%tschchartaxiscategory3dgridlinestroke\x18\xcc\x02 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12,\n#tschchartaxisvalue3dgridlineopacity\x18\xcd\x02 \x01(\x02\x12/\n&tschchartaxiscategory3dgridlineopacity\x18\xce\x02 \x01(\x02\"\x8c\x07\n\x18\x43hartAxisNonStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12\x46\n\x1btschchartaxisdefaultusermin\x18\x0b \x01(\x0b\x32!.TSCH.ChartsNSNumberDoubleArchive\x12\x46\n\x1btschchartaxisdefaultusermax\x18\x0c \x01(\x0b\x32!.TSCH.ChartsNSNumberDoubleArchive\x12P\n tschchartaxisdefaultnumberformat\x18\r \x01(\x0b\x32&.TSCH.PreUFF.ChartsNumberFormatArchive\x12&\n\x1etschchartaxisdefaultshowlabels\x18\x0e \x01(\x08\x12\x30\n(tschchartaxisvaluenumberofminorgridlines\x18\x32 \x01(\x05\x12\x1f\n\x17tschchartaxisvaluescale\x18\x33 \x01(\x05\x12)\n!tschchartaxisvaluenumberofdecades\x18\x34 \x01(\x05\x12$\n\x1ctschchartaxisvalueshowlabels\x18\x35 \x01(\x08\x12#\n\x1btschchartaxisvalueshowtitle\x18\x36 \x01(\x08\x12\x30\n(tschchartaxisvaluenumberofmajorgridlines\x18\x37 \x01(\x05\x12\x1f\n\x17tschchartaxisvaluetitle\x18\x38 \x01(\t\x12\'\n\x1ftschchartaxiscategoryshowlabels\x18\x64 \x01(\x08\x12-\n%tschchartaxiscategoryshowserieslabels\x18\x65 \x01(\x08\x12&\n\x1etschchartaxiscategoryshowtitle\x18\x66 \x01(\x08\x12\"\n\x1atschchartaxiscategorytitle\x18g \x01(\t\x12,\n$tschchartaxisdefaultnumberformattype\x18x \x01(\x05\x12,\n#tschchartaxisdefault3dlabelposition\x18\xd0\x02 \x01(\x05\x12(\n tschchartaxiscategoryplottoedges\x18t \x01(\x08\"\xe2/\n\x17\x43hartSeriesStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12\x43\n:tschchartseriesdefaulttrendlineequationparagraphstyleindex\x18\xc9\x01 \x01(\x05\x12\x43\n:tschchartseriesdefaulttrendlinersquaredparagraphstyleindex\x18\xca\x01 \x01(\x05\x12\x37\n.tschchartseriesdefaulttrendlineequationopacity\x18\xcd\x01 \x01(\x02\x12\x37\n.tschchartseriesdefaulttrendlinersquaredopacity\x18\xce\x01 \x01(\x02\x12\x30\n\x16tschchartseriesbarfill\x18\n \x01(\x0b\x32\x10.TSD.FillArchive\x12\x34\n\x18tschchartseriesbarstroke\x18\x0b \x01(\x0b\x32\x12.TSD.StrokeArchive\x12,\n$tschchartseriesbarvaluelabelposition\x18\r \x01(\x05\x12\x35\n\x19tschchartserieslinestroke\x18\x10 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x37\n\x1dtschchartserieslinesymbolfill\x18\x11 \x01(\x0b\x32\x10.TSD.FillArchive\x12;\n\x1ftschchartserieslinesymbolstroke\x18\x12 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12%\n\x1dtschchartserieslinesymbolsize\x18\x14 \x01(\x02\x12-\n%tschchartserieslinevaluelabelposition\x18\x16 \x01(\x05\x12\x31\n\x17tschchartseriesareafill\x18\x19 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x35\n\x19tschchartseriesareastroke\x18\x1a \x01(\x0b\x32\x12.TSD.StrokeArchive\x12-\n%tschchartseriesareavaluelabelposition\x18\x1c \x01(\x05\x12\x37\n\x1dtschchartseriesareasymbolfill\x18\x1d \x01(\x0b\x32\x10.TSD.FillArchive\x12;\n\x1ftschchartseriesareasymbolstroke\x18\x1e \x01(\x0b\x32\x12.TSD.StrokeArchive\x12%\n\x1dtschchartseriesareasymbolsize\x18  \x01(\x02\x12\x30\n\x16tschchartseriespiefill\x18# \x01(\x0b\x32\x10.TSD.FillArchive\x12\x34\n\x18tschchartseriespiestroke\x18$ \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x38\n\x1ctschchartseriesscatterstroke\x18( \x01(\x0b\x32\x12.TSD.StrokeArchive\x12:\n tschchartseriesscattersymbolfill\x18) \x01(\x0b\x32\x10.TSD.FillArchive\x12>\n\"tschchartseriesscattersymbolstroke\x18* \x01(\x0b\x32\x12.TSD.StrokeArchive\x12(\n tschchartseriesscattersymbolsize\x18, \x01(\x02\x12\x30\n(tschchartseriesscattervaluelabelposition\x18. \x01(\x05\x12\x34\n\x1atschchartseriesdefaultfill\x18\x32 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x30\n(tschchartseriesdefaultvaluelabelposition\x18\x34 \x01(\x05\x12\x32\n*tschchartseriespiedeprecatedserieslabelson\x18< \x01(\x08\x12\x33\n\x19tschchartseriescolumnfill\x18> \x01(\x0b\x32\x10.TSD.FillArchive\x12\x34\n\x18tschchartseriespieshadow\x18\x64 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x34\n\x18tschchartseriesbarshadow\x18\x65 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x35\n\x19tschchartseriesareashadow\x18\x66 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x38\n\x1ctschchartseriesscattershadow\x18g \x01(\x0b\x32\x12.TSD.ShadowArchive\x12:\n\x1etschchartseriesmixedlineshadow\x18h \x01(\x0b\x32\x12.TSD.ShadowArchive\x12:\n\x1etschchartseriesmixedareashadow\x18i \x01(\x0b\x32\x12.TSD.ShadowArchive\x12<\n tschchartseriesmixedcolumnshadow\x18j \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x35\n\x19tschchartserieslineshadow\x18k \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x38\n\x1ctschchartseriesdefaultshadow\x18l \x01(\x0b\x32\x12.TSD.ShadowArchive\x12:\n\x1ftschchartseriesbubblesymbolfill\x18\xcf\x01 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x38\n\x1btschchartseriesbubblestroke\x18\xd3\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12>\n!tschchartseriesbubblesymbolstroke\x18\xd4\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x30\n\'tschchartseriesbubblevaluelabelposition\x18\xd5\x01 \x01(\x05\x12\x38\n\x1btschchartseriesbubbleshadow\x18\xd6\x01 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x37\n.tschchartseriesbubblesymbolfilluseseriesstroke\x18\xd7\x01 \x01(\x08\x12\x37\n\x1atschchartseries3dbarshadow\x18\xb2\x02 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12:\n\x1dtschchartseries3dcolumnshadow\x18\xb3\x02 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x38\n\x1btschchartseries3dlineshadow\x18\xb4\x02 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x38\n\x1btschchartseries3dareashadow\x18\xb5\x02 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x37\n\x1atschchartseries3dpieshadow\x18\xb6\x02 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x36\n.tschchartseriesdefaultlabelparagraphstyleindex\x18n \x01(\x05\x12\x32\n*tschchartseriesbarlabelparagraphstyleindex\x18o \x01(\x05\x12\x33\n+tschchartserieslinelabelparagraphstyleindex\x18p \x01(\x05\x12\x33\n+tschchartseriesarealabelparagraphstyleindex\x18q \x01(\x05\x12\x32\n*tschchartseriespielabelparagraphstyleindex\x18r \x01(\x05\x12\x34\n,tschchartseriesmixedlabelparagraphstyleindex\x18s \x01(\x05\x12%\n\x1dtschchartseriesdefaultopacity\x18t \x01(\x02\x12\x34\n,tschchartserieslinesymbolfilluseseriesstroke\x18u \x01(\x08\x12\x34\n,tschchartseriesareasymbolfilluseseriesstroke\x18v \x01(\x08\x12\x37\n/tschchartseriesscattersymbolfilluseseriesstroke\x18w \x01(\x08\x12\x39\n1tschchartseriesmixedlinesymbolfilluseseriesstroke\x18x \x01(\x08\x12\x39\n1tschchartseriesmixedareasymbolfilluseseriesstroke\x18y \x01(\x08\x12\x32\n*tschchartserieslinesymbolfilluseseriesfill\x18z \x01(\x08\x12\x32\n*tschchartseriesareasymbolfilluseseriesfill\x18{ \x01(\x08\x12\x37\n/tschchartseriesmixedlinesymbolfilluseseriesfill\x18| \x01(\x08\x12\x37\n/tschchartseriesmixedareasymbolfilluseseriesfill\x18} \x01(\x08\x12\x39\n\x1etschchartseriesmixedcolumnfill\x18\x82\x01 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x37\n\x1ctschchartseriesmixedareafill\x18\x83\x01 \x01(\x0b\x32\x10.TSD.FillArchive\x12=\n tschchartseriesmixedcolumnstroke\x18\x84\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12;\n\x1etschchartseriesmixedlinestroke\x18\x85\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12;\n\x1etschchartseriesmixedareastroke\x18\x86\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12+\n\"tschchartseriesmixedlinesymbolsize\x18\x87\x01 \x01(\x02\x12+\n\"tschchartseriesmixedareasymbolsize\x18\x88\x01 \x01(\x02\x12=\n\"tschchartseriesmixedlinesymbolfill\x18\x89\x01 \x01(\x0b\x32\x10.TSD.FillArchive\x12=\n\"tschchartseriesmixedareasymbolfill\x18\x8a\x01 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x41\n$tschchartseriesmixedlinesymbolstroke\x18\x8b\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x41\n$tschchartseriesmixedareasymbolstroke\x18\x8c\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x35\n,tschchartseriesmixedcolumnvaluelabelposition\x18\x8d\x01 \x01(\x05\x12\x33\n*tschchartseriesmixedlinevaluelabelposition\x18\x8e\x01 \x01(\x05\x12\x33\n*tschchartseriesmixedareavaluelabelposition\x18\x8f\x01 \x01(\x05\x12>\n5tschchartseriesdefaultoutsidelabelparagraphstyleindex\x18\x96\x01 \x01(\x05\x12:\n1tschchartseriesbaroutsidelabelparagraphstyleindex\x18\x97\x01 \x01(\x05\x12;\n2tschchartseriesareaoutsidelabelparagraphstyleindex\x18\x99\x01 \x01(\x05\x12:\n1tschchartseriespieoutsidelabelparagraphstyleindex\x18\x9a\x01 \x01(\x05\x12<\n3tschchartseriesmixedoutsidelabelparagraphstyleindex\x18\x9b\x01 \x01(\x05\x12\x34\n+tschchartseriesstackedbarvaluelabelposition\x18\x9c\x01 \x01(\x05\x12\x35\n,tschchartseriesstackedareavaluelabelposition\x18\x9d\x01 \x01(\x05\x12\x42\n%tschchartseriesdefaulttrendlinestroke\x18\xa7\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x42\n%tschchartseriesdefaulttrendlineshadow\x18\xa8\x01 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x41\n$tschchartseriesdefaulterrorbarshadow\x18\xb4\x01 \x01(\x0b\x32\x12.TSD.ShadowArchive\x12\x41\n$tschchartseriesdefaulterrorbarstroke\x18\xb5\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12I\n,tschchartseriesdefaulterrorbarstrokescatterx\x18\xb6\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x43\n%tschchartseriesdefaulterrorbarlineend\x18\xb7\x01 \x01(\x0b\x32\x13.TSD.LineEndArchive\x12K\n-tschchartseriesdefaulterrorbarlineendscatterx\x18\xb8\x01 \x01(\x0b\x32\x13.TSD.LineEndArchive\x12S\n&tschchartseriesdefaultdeprecated3dfill\x18\xac\x02 \x01(\x0b\x32\".TSCH.DEPRECATEDChart3DFillArchive\x12O\n\"tschchartseriesbardeprecated3dfill\x18\xad\x02 \x01(\x0b\x32\".TSCH.DEPRECATEDChart3DFillArchive\x12R\n%tschchartseriescolumndeprecated3dfill\x18\xae\x02 \x01(\x0b\x32\".TSCH.DEPRECATEDChart3DFillArchive\x12P\n#tschchartserieslinedeprecated3dfill\x18\xaf\x02 \x01(\x0b\x32\".TSCH.DEPRECATEDChart3DFillArchive\x12P\n#tschchartseriesareadeprecated3dfill\x18\xb0\x02 \x01(\x0b\x32\".TSCH.DEPRECATEDChart3DFillArchive\x12O\n\"tschchartseriespiedeprecated3dfill\x18\xb1\x02 \x01(\x0b\x32\".TSCH.DEPRECATEDChart3DFillArchive\x12\x33\n\x18tschchartseries3dbarfill\x18\xc0\x02 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x36\n\x1btschchartseries3dcolumnfill\x18\xc1\x02 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x34\n\x19tschchartseries3dlinefill\x18\xc2\x02 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x34\n\x19tschchartseries3dareafill\x18\xc3\x02 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x33\n\x18tschchartseries3dpiefill\x18\xc4\x02 \x01(\x0b\x32\x10.TSD.FillArchive\"\xe4\x1a\n\x1a\x43hartSeriesNonStyleArchive\x12 \n\x05super\x18\x01 \x02(\x0b\x32\x11.TSS.StyleArchive\x12R\n\"tschchartseriesdefaultnumberformat\x18\n \x01(\x0b\x32&.TSCH.PreUFF.ChartsNumberFormatArchive\x12.\n&tschchartseriesdefaultnumberformattype\x18\x0b \x01(\x05\x12)\n!tschchartseriesbarshowvaluelabels\x18\x0c \x01(\x08\x12%\n\x1dtschchartserieslinesymboltype\x18\x13 \x01(\x05\x12%\n\x1dtschchartserieslineshowsymbol\x18\x14 \x01(\x08\x12*\n\"tschchartserieslineshowvaluelabels\x18\x15 \x01(\x08\x12*\n\"tschchartseriesareashowvaluelabels\x18\x1b \x01(\x08\x12#\n\x1btschchartserieslinelinetype\x18\x1e \x01(\x05\x12%\n\x1dtschchartseriesareasymboltype\x18\x1f \x01(\x05\x12%\n\x1dtschchartseriesareashowsymbol\x18  \x01(\x08\x12)\n!tschchartseriespieshowvaluelabels\x18% \x01(\x08\x12-\n%tschchartseriesscattershowvaluelabels\x18- \x01(\x08\x12(\n tschchartseriespiewedgeexplosion\x18\x32 \x01(\x02\x12-\n%tschchartseriesdefaultshowvaluelabels\x18\x33 \x01(\x08\x12N\n\x1etschchartseriespienumberformat\x18\x34 \x01(\x0b\x32&.TSCH.PreUFF.ChartsNumberFormatArchive\x12*\n\"tschchartseriespienumberformattype\x18\x35 \x01(\x05\x12(\n tschchartseriespielabelexplosion\x18\x36 \x01(\x02\x12*\n\"tschchartseriesmixedlineshowsymbol\x18: \x01(\x08\x12*\n\"tschchartseriesmixedareashowsymbol\x18; \x01(\x08\x12*\n\"tschchartseriesmixedlinesymboltype\x18< \x01(\x05\x12*\n\"tschchartseriesmixedareasymboltype\x18= \x01(\x05\x12+\n#tschchartseriesmixedshowvaluelabels\x18> \x01(\x08\x12(\n tschchartseriesmixedlinelinetype\x18? \x01(\x05\x12*\n\"tschchartseriesdefaultyaxisordinal\x18\x41 \x01(\x05\x12*\n\"tschchartseriespieshowserieslabels\x18\x42 \x01(\x08\x12(\n tschchartseriesscattershowsymbol\x18\x45 \x01(\x08\x12(\n tschchartseriesscattersymboltype\x18\x46 \x01(\x05\x12&\n\x1etschchartseriesscatterlinetype\x18G \x01(\x05\x12&\n\x1etschchartseriesscattershowline\x18H \x01(\x08\x12Y\n)tschchartseriesstackedpercentnumberformat\x18Z \x01(\x0b\x32&.TSCH.PreUFF.ChartsNumberFormatArchive\x12(\n tschchartseriesdefaultseriestype\x18~ \x01(\x05\x12,\n#tschchartseriesdefaulttrendlinetype\x18\xa0\x01 \x01(\x05\x12-\n$tschchartseriesdefaulttrendlineorder\x18\xa1\x01 \x01(\x05\x12.\n%tschchartseriesdefaulttrendlineperiod\x18\xa2\x01 \x01(\x05\x12\x31\n(tschchartseriesdefaulttrendlineshowlabel\x18\xa3\x01 \x01(\x08\x12\x33\n*tschchartseriesdefaulttrendlinelabelstring\x18\xa4\x01 \x01(\t\x12\x34\n+tschchartseriesdefaulttrendlineshowequation\x18\xa5\x01 \x01(\x08\x12\x33\n*tschchartseriesdefaulttrendlineshowr2value\x18\xa6\x01 \x01(\x08\x12.\n%tschchartseriesdefaulterrorbarsetting\x18\xaa\x01 \x01(\x05\x12\x36\n-tschchartseriesdefaulterrorbarsettingscatterx\x18\xab\x01 \x01(\x05\x12+\n\"tschchartseriesdefaulterrorbartype\x18\xac\x01 \x01(\x05\x12\x33\n*tschchartseriesdefaulterrorbartypescatterx\x18\xad\x01 \x01(\x05\x12\x31\n(tschchartseriesdefaulterrorbarfixedvalue\x18\xae\x01 \x01(\x02\x12\x39\n0tschchartseriesdefaulterrorbarfixedvaluescatterx\x18\xaf\x01 \x01(\x02\x12\x33\n*tschchartseriesdefaulterrorbarpercentvalue\x18\xb0\x01 \x01(\x02\x12;\n2tschchartseriesdefaulterrorbarpercentvaluescatterx\x18\xb1\x01 \x01(\x02\x12\x32\n)tschchartseriesdefaulterrorbarstddevvalue\x18\xb2\x01 \x01(\x02\x12:\n1tschchartseriesdefaulterrorbarstddevvaluescatterx\x18\xb3\x01 \x01(\x02\x12\x65\n0tschchartseriesdefaulterrorbarcustompositivedata\x18\xbe\x01 \x01(\x0b\x32*.TSCH.ChartsNSArrayOfNSNumberDoubleArchive\x12m\n8tschchartseriesdefaulterrorbarcustompositivedatascatterx\x18\xbf\x01 \x01(\x0b\x32*.TSCH.ChartsNSArrayOfNSNumberDoubleArchive\x12\x65\n0tschchartseriesdefaulterrorbarcustomnegativedata\x18\xc0\x01 \x01(\x0b\x32*.TSCH.ChartsNSArrayOfNSNumberDoubleArchive\x12m\n8tschchartseriesdefaulterrorbarcustomnegativedatascatterx\x18\xc1\x01 \x01(\x0b\x32*.TSCH.ChartsNSArrayOfNSNumberDoubleArchive\x12\x37\n.tschchartseriesdefaulttrendlineequationoffsetx\x18\xc2\x01 \x01(\x02\x12\x37\n.tschchartseriesdefaulttrendlineequationoffsety\x18\xc3\x01 \x01(\x02\x12\x37\n.tschchartseriesdefaulttrendlinersquaredoffsetx\x18\xc4\x01 \x01(\x02\x12\x37\n.tschchartseriesdefaulttrendlinersquaredoffsety\x18\xc5\x01 \x01(\x02\x12,\n#tschchartseriesdefaultshowtrendline\x18\xc6\x01 \x01(\x08\x12+\n\"tschchartseriesdefaultshowerrorbar\x18\xc7\x01 \x01(\x08\x12\x33\n*tschchartseriesdefaultshowerrorbarscatterx\x18\xc8\x01 \x01(\x08\x12+\n\"tschchartseriesbubblesizedimension\x18\xd0\x01 \x01(\x05\x12-\n$tschchartseriesbubbleshowvaluelabels\x18\xd1\x01 \x01(\x08\x12&\n\x1dtschchartseriesbubblelinetype\x18\xd2\x01 \x01(\x05\x12.\n%tschchartseriesbubbleshownegativedata\x18\xd8\x01 \x01(\x08\x12-\n$tschchartseriesbubbleadjustmentscale\x18\xd9\x01 \x01(\x02')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSDArchives__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSCHArchives__Common__pb2.DESCRIPTOR,TSCH3DArchives__pb2.DESCRIPTOR,])




_CHARTINFOARCHIVE = _descriptor.Descriptor(
  name='ChartInfoArchive',
  full_name='TSCH.PreUFF.ChartInfoArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.PreUFF.ChartInfoArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chart_model', full_name='TSCH.PreUFF.ChartInfoArchive.chart_model', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='TSCH.PreUFF.ChartInfoArchive.style', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chart_type', full_name='TSCH.PreUFF.ChartInfoArchive.chart_type', index=3,
      number=4, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legend_model', full_name='TSCH.PreUFF.ChartInfoArchive.legend_model', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inner_chart_frame', full_name='TSCH.PreUFF.ChartInfoArchive.inner_chart_frame', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_axis_styles', full_name='TSCH.PreUFF.ChartInfoArchive.value_axis_styles', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_axis_styles', full_name='TSCH.PreUFF.ChartInfoArchive.category_axis_styles', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_axis_nonstyles', full_name='TSCH.PreUFF.ChartInfoArchive.value_axis_nonstyles', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_axis_nonstyles', full_name='TSCH.PreUFF.ChartInfoArchive.category_axis_nonstyles', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_theme_styles', full_name='TSCH.PreUFF.ChartInfoArchive.series_theme_styles', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_private_styles', full_name='TSCH.PreUFF.ChartInfoArchive.series_private_styles', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_non_styles', full_name='TSCH.PreUFF.ChartInfoArchive.series_non_styles', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='non_style', full_name='TSCH.PreUFF.ChartInfoArchive.non_style', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mediator', full_name='TSCH.PreUFF.ChartInfoArchive.mediator', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cde_preview_origin', full_name='TSCH.PreUFF.ChartInfoArchive.cde_preview_origin', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chart_style_preset', full_name='TSCH.PreUFF.ChartInfoArchive.chart_style_preset', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_styles', full_name='TSCH.PreUFF.ChartInfoArchive.paragraph_styles', index=17,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_row_sected_in_the_cde', full_name='TSCH.PreUFF.ChartInfoArchive.last_row_sected_in_the_cde', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_column_sected_in_the_cde', full_name='TSCH.PreUFF.ChartInfoArchive.last_column_sected_in_the_cde', index=19,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chart_style_preset_index', full_name='TSCH.PreUFF.ChartInfoArchive.chart_style_preset_index', index=20,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='needs_calc_engine_deferred_import_action', full_name='TSCH.PreUFF.ChartInfoArchive.needs_calc_engine_deferred_import_action', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=1139,
)


_LEGENDMODELARCHIVE = _descriptor.Descriptor(
  name='LegendModelArchive',
  full_name='TSCH.PreUFF.LegendModelArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='TSCH.PreUFF.LegendModelArchive.info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame', full_name='TSCH.PreUFF.LegendModelArchive.frame', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='TSCH.PreUFF.LegendModelArchive.style', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='non_style', full_name='TSCH.PreUFF.LegendModelArchive.non_style', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1142,
  serialized_end=1292,
)


_CHARTMODELARCHIVE = _descriptor.Descriptor(
  name='ChartModelArchive',
  full_name='TSCH.PreUFF.ChartModelArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='TSCH.PreUFF.ChartModelArchive.info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grid', full_name='TSCH.PreUFF.ChartModelArchive.grid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_types', full_name='TSCH.PreUFF.ChartModelArchive.series_types', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scatter_format', full_name='TSCH.PreUFF.ChartModelArchive.scatter_format', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inline_grid', full_name='TSCH.PreUFF.ChartModelArchive.inline_grid', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multidataset_index', full_name='TSCH.PreUFF.ChartModelArchive.multidataset_index', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1295,
  serialized_end=1500,
)


_CHARTGRIDARCHIVE_VALUEROW = _descriptor.Descriptor(
  name='ValueRow',
  full_name='TSCH.PreUFF.ChartGridArchive.ValueRow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='TSCH.PreUFF.ChartGridArchive.ValueRow.value', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1655,
  serialized_end=1680,
)

_CHARTGRIDARCHIVE = _descriptor.Descriptor(
  name='ChartGridArchive',
  full_name='TSCH.PreUFF.ChartGridArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='direction', full_name='TSCH.PreUFF.ChartGridArchive.direction', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_name', full_name='TSCH.PreUFF.ChartGridArchive.row_name', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_name', full_name='TSCH.PreUFF.ChartGridArchive.column_name', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_row', full_name='TSCH.PreUFF.ChartGridArchive.value_row', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dirty', full_name='TSCH.PreUFF.ChartGridArchive.dirty', index=4,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CHARTGRIDARCHIVE_VALUEROW, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1503,
  serialized_end=1680,
)


_CHARTSNUMBERFORMATARCHIVE = _descriptor.Descriptor(
  name='ChartsNumberFormatArchive',
  full_name='TSCH.PreUFF.ChartsNumberFormatArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value_type', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.value_type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_string', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.format_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_places', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.decimal_places', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.currency_code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='negative_style', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.negative_style', index=4,
      number=5, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_thousands_separator', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.show_thousands_separator', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fraction_accuracy', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.fraction_accuracy', index=6,
      number=7, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suffix_string', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.suffix_string', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.base', index=8,
      number=9, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_places', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.base_places', index=9,
      number=10, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_use_minus_sign', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.base_use_minus_sign', index=10,
      number=11, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_accounting_style', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.use_accounting_style', index=11,
      number=12, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_custom', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.is_custom', index=12,
      number=13, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scale_factor', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.scale_factor', index=13,
      number=14, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interstitial_strings', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.interstitial_strings', index=14,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interstitial_string_insertion_indexes', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.interstitial_string_insertion_indexes', index=15,
      number=16, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index_from_right_of_last_digit_placeholder', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.index_from_right_of_last_digit_placeholder', index=16,
      number=17, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_text_format', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.is_text_format', index=17,
      number=18, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minimum_integer_width', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.minimum_integer_width', index=18,
      number=19, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_width', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.decimal_width', index=19,
      number=20, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_non_space_integer_placeholder_digits', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.number_of_non_space_integer_placeholder_digits', index=20,
      number=21, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_non_space_decimal_placeholder_digits', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.number_of_non_space_decimal_placeholder_digits', index=21,
      number=22, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_name', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.format_name', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prefix_string', full_name='TSCH.PreUFF.ChartsNumberFormatArchive.prefix_string', index=23,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1683,
  serialized_end=2495,
)


_CHARTSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartStyleArchive',
  full_name='TSCH.PreUFF.ChartStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.PreUFF.ChartStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultbackgroundfill', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultbackgroundfill', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultbackgroundstroke', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultbackgroundstroke', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultgridbackgroundfill', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultgridbackgroundfill', index=3,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultintersetgap', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultintersetgap', index=4,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultinterbargap', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultinterbargap', index=5,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultshowborder', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultshowborder', index=6,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultborderstroke', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultborderstroke', index=7,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaulttitlecolor', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaulttitlecolor', index=8,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultgridbackgroundopacity', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultgridbackgroundopacity', index=9,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultcombinelayers', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultcombinelayers', index=10,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultbordershadow', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultbordershadow', index=11,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultborderopacity', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultborderopacity', index=12,
      number=22, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaulttitleparagraphstyleindex', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaulttitleparagraphstyleindex', index=13,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdeprecatedmasterfontfamily', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultdeprecatedmasterfontfamily', index=14,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdeprecatedmasterfontnamedsize', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultdeprecatedmasterfontnamedsize', index=15,
      number=25, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdeprecatedtrendlineequationparagraphstyleindex', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultdeprecatedtrendlineequationparagraphstyleindex', index=16,
      number=30, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdeprecatedtrendlinersquaredparagraphstyleindex', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultdeprecatedtrendlinersquaredparagraphstyleindex', index=17,
      number=31, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdeprecatedtrendlineequationshadow', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultdeprecatedtrendlineequationshadow', index=18,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdeprecatedtrendlinersquaredshadow', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultdeprecatedtrendlinersquaredshadow', index=19,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdeprecatedtrendlineequationopacity', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultdeprecatedtrendlineequationopacity', index=20,
      number=34, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdeprecatedtrendlinersquaredopacity', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultdeprecatedtrendlinersquaredopacity', index=21,
      number=35, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfobardeprecated3dshadow', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfobardeprecated3dshadow', index=22,
      number=308, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfocolumndeprecated3dshadow', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfocolumndeprecated3dshadow', index=23,
      number=309, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfolinedeprecated3dshadow', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfolinedeprecated3dshadow', index=24,
      number=310, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoareadeprecated3dshadow', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfoareadeprecated3dshadow', index=25,
      number=311, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfopiedeprecated3dshadow', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfopiedeprecated3dshadow', index=26,
      number=312, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefault3dlightingpackage', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefault3dlightingpackage', index=27,
      number=313, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfocolumn3dlightingpackage', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfocolumn3dlightingpackage', index=28,
      number=314, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfobar3dlightingpackage', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfobar3dlightingpackage', index=29,
      number=315, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoline3dlightingpackage', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfoline3dlightingpackage', index=30,
      number=316, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoarea3dlightingpackage', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfoarea3dlightingpackage', index=31,
      number=317, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfopie3dlightingpackage', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfopie3dlightingpackage', index=32,
      number=318, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdeprecated3dbeveledges', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultdeprecated3dbeveledges', index=33,
      number=326, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfopiedeprecated3dbeveledges', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfopiedeprecated3dbeveledges', index=34,
      number=327, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfobardeprecated3dbeveledges', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfobardeprecated3dbeveledges', index=35,
      number=328, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfocolumndeprecated3dbeveledges', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfocolumndeprecated3dbeveledges', index=36,
      number=329, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdeprecated3dbarshape', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefaultdeprecated3dbarshape', index=37,
      number=330, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefault3dchartopacity', full_name='TSCH.PreUFF.ChartStyleArchive.tschchartinfodefault3dchartopacity', index=38,
      number=335, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2498,
  serialized_end=4919,
)


_CHARTNONSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartNonStyleArchive',
  full_name='TSCH.PreUFF.ChartNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.PreUFF.ChartNonStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaulttitle', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfodefaulttitle', index=1,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultshowlegend', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfodefaultshowlegend', index=2,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultpiestartangle', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfodefaultpiestartangle', index=3,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultshowtitle', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfodefaultshowtitle', index=4,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdeprecatedagainmasterfontnamedsize', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfodefaultdeprecatedagainmasterfontnamedsize', index=5,
      number=25, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefault3drotation', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfodefault3drotation', index=6,
      number=300, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefault3dscale', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfodefault3dscale', index=7,
      number=301, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfocolumn3dscale', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfocolumn3dscale', index=8,
      number=302, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfobar3dscale', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfobar3dscale', index=9,
      number=303, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoline3dscale', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfoline3dscale', index=10,
      number=304, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoarea3dscale', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfoarea3dscale', index=11,
      number=305, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfopie3dscale', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfopie3dscale', index=12,
      number=306, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefault3dviewport', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfodefault3dviewport', index=13,
      number=313, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultdeprecated3dlightingpackage', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfodefaultdeprecated3dlightingpackage', index=14,
      number=320, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfocolumndeprecated3dlightingpackage', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfocolumndeprecated3dlightingpackage', index=15,
      number=321, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfobardeprecated3dlightingpackage', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfobardeprecated3dlightingpackage', index=16,
      number=322, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfolinedeprecated3dlightingpackage', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfolinedeprecated3dlightingpackage', index=17,
      number=323, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfoareadeprecated3dlightingpackage', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfoareadeprecated3dlightingpackage', index=18,
      number=324, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfopiedeprecated3dlightingpackage', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfopiedeprecated3dlightingpackage', index=19,
      number=325, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefaultskiphiddendata', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfodefaultskiphiddendata', index=20,
      number=326, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefault3dbeveledges', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfodefault3dbeveledges', index=21,
      number=327, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefault3dbarshape', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfodefault3dbarshape', index=22,
      number=336, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartinfodefault3dintersetdepthgap', full_name='TSCH.PreUFF.ChartNonStyleArchive.tschchartinfodefault3dintersetdepthgap', index=23,
      number=331, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4922,
  serialized_end=6451,
)


_LEGENDSTYLEARCHIVE = _descriptor.Descriptor(
  name='LegendStyleArchive',
  full_name='TSCH.PreUFF.LegendStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.PreUFF.LegendStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschlegendmodeldefaultfill', full_name='TSCH.PreUFF.LegendStyleArchive.tschlegendmodeldefaultfill', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschlegendmodeldefaultstroke', full_name='TSCH.PreUFF.LegendStyleArchive.tschlegendmodeldefaultstroke', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschlegendmodeldefaultshadow', full_name='TSCH.PreUFF.LegendStyleArchive.tschlegendmodeldefaultshadow', index=3,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschlegendmodeldefaultopacity', full_name='TSCH.PreUFF.LegendStyleArchive.tschlegendmodeldefaultopacity', index=4,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschlegendmodeldefaultlabelparagraphstyleindex', full_name='TSCH.PreUFF.LegendStyleArchive.tschlegendmodeldefaultlabelparagraphstyleindex', index=5,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6454,
  serialized_end=6773,
)


_LEGENDNONSTYLEARCHIVE = _descriptor.Descriptor(
  name='LegendNonStyleArchive',
  full_name='TSCH.PreUFF.LegendNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.PreUFF.LegendNonStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6775,
  serialized_end=6832,
)


_CHARTAXISSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartAxisStyleArchive',
  full_name='TSCH.PreUFF.ChartAxisStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.PreUFF.ChartAxisStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueshowmajorgridlines', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvalueshowmajorgridlines', index=1,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueshowminorgridlines', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvalueshowminorgridlines', index=2,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluemajorgridlinestroke', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvaluemajorgridlinestroke', index=3,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueminorgridlinestroke', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvalueminorgridlinestroke', index=4,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluetickmarklocation', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvaluetickmarklocation', index=5,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueshowmajortickmarks', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvalueshowmajortickmarks', index=6,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueshowminortickmarks', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvalueshowminortickmarks', index=7,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluelabelsorientation', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvaluelabelsorientation', index=8,
      number=17, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueshowminimumlabel', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvalueshowminimumlabel', index=9,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluemajorgridlineshadow', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvaluemajorgridlineshadow', index=10,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueminorgridlineshadow', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvalueminorgridlineshadow', index=11,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluemajorgridlineopacity', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvaluemajorgridlineopacity', index=12,
      number=23, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueminorgridlineopacity', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvalueminorgridlineopacity', index=13,
      number=24, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueshowaxis', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvalueshowaxis', index=14,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowmajorgridlines', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategoryshowmajorgridlines', index=15,
      number=50, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowminorgridlines', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategoryshowminorgridlines', index=16,
      number=51, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategorymajorgridlinestroke', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategorymajorgridlinestroke', index=17,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryminorgridlinestroke', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategoryminorgridlinestroke', index=18,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategorytickmarklocation', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategorytickmarklocation', index=19,
      number=54, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowmajortickmarks', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategoryshowmajortickmarks', index=20,
      number=55, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowminortickmarks', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategoryshowminortickmarks', index=21,
      number=56, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategorylabelsorientation', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategorylabelsorientation', index=22,
      number=57, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryhorizontalspacing', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategoryhorizontalspacing', index=23,
      number=58, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryverticalspacing', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategoryverticalspacing', index=24,
      number=59, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowlastlabel', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategoryshowlastlabel', index=25,
      number=60, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategorymajorgridlineshadow', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategorymajorgridlineshadow', index=26,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryminorgridlineshadow', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategoryminorgridlineshadow', index=27,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategorymajorgridlineopacity', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategorymajorgridlineopacity', index=28,
      number=65, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryminorgridlineopacity', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategoryminorgridlineopacity', index=29,
      number=66, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowaxis', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategoryshowaxis', index=30,
      number=67, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaultlabelsorientation', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisdefaultlabelsorientation', index=31,
      number=102, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaulttitleparagraphstyleindex', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisdefaulttitleparagraphstyleindex', index=32,
      number=110, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaultlabelparagraphstyleindex', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisdefaultlabelparagraphstyleindex', index=33,
      number=111, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluetitleparagraphstyleindex', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvaluetitleparagraphstyleindex', index=34,
      number=112, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluelabelparagraphstyleindex', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvaluelabelparagraphstyleindex', index=35,
      number=113, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategorytitleparagraphstyleindex', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategorytitleparagraphstyleindex', index=36,
      number=114, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategorylabelparagraphstyleindex', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategorylabelparagraphstyleindex', index=37,
      number=115, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalue3dgridlinestroke', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvalue3dgridlinestroke', index=38,
      number=331, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategory3dgridlinestroke', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategory3dgridlinestroke', index=39,
      number=332, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalue3dgridlineopacity', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxisvalue3dgridlineopacity', index=40,
      number=333, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategory3dgridlineopacity', full_name='TSCH.PreUFF.ChartAxisStyleArchive.tschchartaxiscategory3dgridlineopacity', index=41,
      number=334, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6835,
  serialized_end=9056,
)


_CHARTAXISNONSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartAxisNonStyleArchive',
  full_name='TSCH.PreUFF.ChartAxisNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaultusermin', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxisdefaultusermin', index=1,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaultusermax', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxisdefaultusermax', index=2,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaultnumberformat', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxisdefaultnumberformat', index=3,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaultshowlabels', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxisdefaultshowlabels', index=4,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluenumberofminorgridlines', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxisvaluenumberofminorgridlines', index=5,
      number=50, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluescale', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxisvaluescale', index=6,
      number=51, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluenumberofdecades', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxisvaluenumberofdecades', index=7,
      number=52, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueshowlabels', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxisvalueshowlabels', index=8,
      number=53, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvalueshowtitle', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxisvalueshowtitle', index=9,
      number=54, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluenumberofmajorgridlines', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxisvaluenumberofmajorgridlines', index=10,
      number=55, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisvaluetitle', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxisvaluetitle', index=11,
      number=56, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowlabels', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxiscategoryshowlabels', index=12,
      number=100, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowserieslabels', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxiscategoryshowserieslabels', index=13,
      number=101, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryshowtitle', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxiscategoryshowtitle', index=14,
      number=102, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategorytitle', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxiscategorytitle', index=15,
      number=103, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefaultnumberformattype', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxisdefaultnumberformattype', index=16,
      number=120, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxisdefault3dlabelposition', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxisdefault3dlabelposition', index=17,
      number=336, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartaxiscategoryplottoedges', full_name='TSCH.PreUFF.ChartAxisNonStyleArchive.tschchartaxiscategoryplottoedges', index=18,
      number=116, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9059,
  serialized_end=9967,
)


_CHARTSERIESSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartSeriesStyleArchive',
  full_name='TSCH.PreUFF.ChartSeriesStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineequationparagraphstyleindex', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaulttrendlineequationparagraphstyleindex', index=1,
      number=201, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlinersquaredparagraphstyleindex', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaulttrendlinersquaredparagraphstyleindex', index=2,
      number=202, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineequationopacity', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaulttrendlineequationopacity', index=3,
      number=205, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlinersquaredopacity', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaulttrendlinersquaredopacity', index=4,
      number=206, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbarfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesbarfill', index=5,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbarstroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesbarstroke', index=6,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbarvaluelabelposition', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesbarvaluelabelposition', index=7,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinestroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartserieslinestroke', index=8,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinesymbolfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartserieslinesymbolfill', index=9,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinesymbolstroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartserieslinesymbolstroke', index=10,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinesymbolsize', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartserieslinesymbolsize', index=11,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinevaluelabelposition', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartserieslinevaluelabelposition', index=12,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareafill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesareafill', index=13,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareastroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesareastroke', index=14,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareavaluelabelposition', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesareavaluelabelposition', index=15,
      number=28, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareasymbolfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesareasymbolfill', index=16,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareasymbolstroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesareasymbolstroke', index=17,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareasymbolsize', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesareasymbolsize', index=18,
      number=32, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespiefill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriespiefill', index=19,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespiestroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriespiestroke', index=20,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscatterstroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesscatterstroke', index=21,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattersymbolfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesscattersymbolfill', index=22,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattersymbolstroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesscattersymbolstroke', index=23,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattersymbolsize', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesscattersymbolsize', index=24,
      number=44, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattervaluelabelposition', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesscattervaluelabelposition', index=25,
      number=46, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaultfill', index=26,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultvaluelabelposition', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaultvaluelabelposition', index=27,
      number=52, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespiedeprecatedserieslabelson', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriespiedeprecatedserieslabelson', index=28,
      number=60, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriescolumnfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriescolumnfill', index=29,
      number=62, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespieshadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriespieshadow', index=30,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbarshadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesbarshadow', index=31,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareashadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesareashadow', index=32,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattershadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesscattershadow', index=33,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlineshadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedlineshadow', index=34,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareashadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedareashadow', index=35,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedcolumnshadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedcolumnshadow', index=36,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslineshadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartserieslineshadow', index=37,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultshadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaultshadow', index=38,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubblesymbolfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesbubblesymbolfill', index=39,
      number=207, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubblestroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesbubblestroke', index=40,
      number=211, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubblesymbolstroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesbubblesymbolstroke', index=41,
      number=212, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubblevaluelabelposition', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesbubblevaluelabelposition', index=42,
      number=213, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubbleshadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesbubbleshadow', index=43,
      number=214, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubblesymbolfilluseseriesstroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesbubblesymbolfilluseseriesstroke', index=44,
      number=215, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dbarshadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseries3dbarshadow', index=45,
      number=306, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dcolumnshadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseries3dcolumnshadow', index=46,
      number=307, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dlineshadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseries3dlineshadow', index=47,
      number=308, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dareashadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseries3dareashadow', index=48,
      number=309, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dpieshadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseries3dpieshadow', index=49,
      number=310, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultlabelparagraphstyleindex', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaultlabelparagraphstyleindex', index=50,
      number=110, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbarlabelparagraphstyleindex', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesbarlabelparagraphstyleindex', index=51,
      number=111, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinelabelparagraphstyleindex', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartserieslinelabelparagraphstyleindex', index=52,
      number=112, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesarealabelparagraphstyleindex', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesarealabelparagraphstyleindex', index=53,
      number=113, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespielabelparagraphstyleindex', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriespielabelparagraphstyleindex', index=54,
      number=114, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlabelparagraphstyleindex', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedlabelparagraphstyleindex', index=55,
      number=115, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultopacity', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaultopacity', index=56,
      number=116, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinesymbolfilluseseriesstroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartserieslinesymbolfilluseseriesstroke', index=57,
      number=117, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareasymbolfilluseseriesstroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesareasymbolfilluseseriesstroke', index=58,
      number=118, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattersymbolfilluseseriesstroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesscattersymbolfilluseseriesstroke', index=59,
      number=119, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinesymbolfilluseseriesstroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedlinesymbolfilluseseriesstroke', index=60,
      number=120, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareasymbolfilluseseriesstroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedareasymbolfilluseseriesstroke', index=61,
      number=121, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinesymbolfilluseseriesfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartserieslinesymbolfilluseseriesfill', index=62,
      number=122, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareasymbolfilluseseriesfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesareasymbolfilluseseriesfill', index=63,
      number=123, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinesymbolfilluseseriesfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedlinesymbolfilluseseriesfill', index=64,
      number=124, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareasymbolfilluseseriesfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedareasymbolfilluseseriesfill', index=65,
      number=125, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedcolumnfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedcolumnfill', index=66,
      number=130, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareafill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedareafill', index=67,
      number=131, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedcolumnstroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedcolumnstroke', index=68,
      number=132, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinestroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedlinestroke', index=69,
      number=133, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareastroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedareastroke', index=70,
      number=134, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinesymbolsize', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedlinesymbolsize', index=71,
      number=135, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareasymbolsize', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedareasymbolsize', index=72,
      number=136, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinesymbolfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedlinesymbolfill', index=73,
      number=137, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareasymbolfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedareasymbolfill', index=74,
      number=138, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinesymbolstroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedlinesymbolstroke', index=75,
      number=139, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareasymbolstroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedareasymbolstroke', index=76,
      number=140, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedcolumnvaluelabelposition', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedcolumnvaluelabelposition', index=77,
      number=141, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinevaluelabelposition', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedlinevaluelabelposition', index=78,
      number=142, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareavaluelabelposition', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedareavaluelabelposition', index=79,
      number=143, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultoutsidelabelparagraphstyleindex', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaultoutsidelabelparagraphstyleindex', index=80,
      number=150, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbaroutsidelabelparagraphstyleindex', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesbaroutsidelabelparagraphstyleindex', index=81,
      number=151, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareaoutsidelabelparagraphstyleindex', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesareaoutsidelabelparagraphstyleindex', index=82,
      number=153, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespieoutsidelabelparagraphstyleindex', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriespieoutsidelabelparagraphstyleindex', index=83,
      number=154, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedoutsidelabelparagraphstyleindex', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesmixedoutsidelabelparagraphstyleindex', index=84,
      number=155, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesstackedbarvaluelabelposition', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesstackedbarvaluelabelposition', index=85,
      number=156, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesstackedareavaluelabelposition', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesstackedareavaluelabelposition', index=86,
      number=157, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlinestroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaulttrendlinestroke', index=87,
      number=167, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineshadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaulttrendlineshadow', index=88,
      number=168, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarshadow', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaulterrorbarshadow', index=89,
      number=180, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarstroke', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaulterrorbarstroke', index=90,
      number=181, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarstrokescatterx', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaulterrorbarstrokescatterx', index=91,
      number=182, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarlineend', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaulterrorbarlineend', index=92,
      number=183, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarlineendscatterx', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaulterrorbarlineendscatterx', index=93,
      number=184, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultdeprecated3dfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesdefaultdeprecated3dfill', index=94,
      number=300, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbardeprecated3dfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesbardeprecated3dfill', index=95,
      number=301, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriescolumndeprecated3dfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriescolumndeprecated3dfill', index=96,
      number=302, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinedeprecated3dfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartserieslinedeprecated3dfill', index=97,
      number=303, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareadeprecated3dfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriesareadeprecated3dfill', index=98,
      number=304, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespiedeprecated3dfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseriespiedeprecated3dfill', index=99,
      number=305, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dbarfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseries3dbarfill', index=100,
      number=320, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dcolumnfill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseries3dcolumnfill', index=101,
      number=321, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dlinefill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseries3dlinefill', index=102,
      number=322, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dareafill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseries3dareafill', index=103,
      number=323, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseries3dpiefill', full_name='TSCH.PreUFF.ChartSeriesStyleArchive.tschchartseries3dpiefill', index=104,
      number=324, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9970,
  serialized_end=16084,
)


_CHARTSERIESNONSTYLEARCHIVE = _descriptor.Descriptor(
  name='ChartSeriesNonStyleArchive',
  full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultnumberformat', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaultnumberformat', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultnumberformattype', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaultnumberformattype', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbarshowvaluelabels', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesbarshowvaluelabels', index=3,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinesymboltype', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartserieslinesymboltype', index=4,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslineshowsymbol', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartserieslineshowsymbol', index=5,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslineshowvaluelabels', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartserieslineshowvaluelabels', index=6,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareashowvaluelabels', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesareashowvaluelabels', index=7,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartserieslinelinetype', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartserieslinelinetype', index=8,
      number=30, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareasymboltype', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesareasymboltype', index=9,
      number=31, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesareashowsymbol', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesareashowsymbol', index=10,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespieshowvaluelabels', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriespieshowvaluelabels', index=11,
      number=37, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattershowvaluelabels', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesscattershowvaluelabels', index=12,
      number=45, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespiewedgeexplosion', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriespiewedgeexplosion', index=13,
      number=50, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultshowvaluelabels', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaultshowvaluelabels', index=14,
      number=51, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespienumberformat', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriespienumberformat', index=15,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespienumberformattype', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriespienumberformattype', index=16,
      number=53, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespielabelexplosion', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriespielabelexplosion', index=17,
      number=54, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlineshowsymbol', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesmixedlineshowsymbol', index=18,
      number=58, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareashowsymbol', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesmixedareashowsymbol', index=19,
      number=59, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinesymboltype', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesmixedlinesymboltype', index=20,
      number=60, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedareasymboltype', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesmixedareasymboltype', index=21,
      number=61, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedshowvaluelabels', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesmixedshowvaluelabels', index=22,
      number=62, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesmixedlinelinetype', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesmixedlinelinetype', index=23,
      number=63, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultyaxisordinal', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaultyaxisordinal', index=24,
      number=65, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriespieshowserieslabels', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriespieshowserieslabels', index=25,
      number=66, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattershowsymbol', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesscattershowsymbol', index=26,
      number=69, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattersymboltype', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesscattersymboltype', index=27,
      number=70, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscatterlinetype', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesscatterlinetype', index=28,
      number=71, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesscattershowline', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesscattershowline', index=29,
      number=72, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesstackedpercentnumberformat', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesstackedpercentnumberformat', index=30,
      number=90, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultseriestype', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaultseriestype', index=31,
      number=126, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlinetype', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlinetype', index=32,
      number=160, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineorder', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlineorder', index=33,
      number=161, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineperiod', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlineperiod', index=34,
      number=162, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineshowlabel', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlineshowlabel', index=35,
      number=163, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlinelabelstring', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlinelabelstring', index=36,
      number=164, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineshowequation', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlineshowequation', index=37,
      number=165, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineshowr2value', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlineshowr2value', index=38,
      number=166, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarsetting', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarsetting', index=39,
      number=170, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarsettingscatterx', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarsettingscatterx', index=40,
      number=171, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbartype', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbartype', index=41,
      number=172, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbartypescatterx', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbartypescatterx', index=42,
      number=173, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarfixedvalue', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarfixedvalue', index=43,
      number=174, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarfixedvaluescatterx', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarfixedvaluescatterx', index=44,
      number=175, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarpercentvalue', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarpercentvalue', index=45,
      number=176, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarpercentvaluescatterx', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarpercentvaluescatterx', index=46,
      number=177, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarstddevvalue', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarstddevvalue', index=47,
      number=178, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarstddevvaluescatterx', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarstddevvaluescatterx', index=48,
      number=179, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarcustompositivedata', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarcustompositivedata', index=49,
      number=190, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarcustompositivedatascatterx', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarcustompositivedatascatterx', index=50,
      number=191, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarcustomnegativedata', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarcustomnegativedata', index=51,
      number=192, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulterrorbarcustomnegativedatascatterx', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulterrorbarcustomnegativedatascatterx', index=52,
      number=193, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineequationoffsetx', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlineequationoffsetx', index=53,
      number=194, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlineequationoffsety', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlineequationoffsety', index=54,
      number=195, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlinersquaredoffsetx', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlinersquaredoffsetx', index=55,
      number=196, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaulttrendlinersquaredoffsety', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaulttrendlinersquaredoffsety', index=56,
      number=197, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultshowtrendline', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaultshowtrendline', index=57,
      number=198, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultshowerrorbar', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaultshowerrorbar', index=58,
      number=199, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesdefaultshowerrorbarscatterx', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesdefaultshowerrorbarscatterx', index=59,
      number=200, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubblesizedimension', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesbubblesizedimension', index=60,
      number=208, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubbleshowvaluelabels', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesbubbleshowvaluelabels', index=61,
      number=209, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubblelinetype', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesbubblelinetype', index=62,
      number=210, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubbleshownegativedata', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesbubbleshownegativedata', index=63,
      number=216, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tschchartseriesbubbleadjustmentscale', full_name='TSCH.PreUFF.ChartSeriesNonStyleArchive.tschchartseriesbubbleadjustmentscale', index=64,
      number=217, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16087,
  serialized_end=19515,
)

_CHARTINFOARCHIVE.fields_by_name['super'].message_type = TSDArchives__pb2._DRAWABLEARCHIVE
_CHARTINFOARCHIVE.fields_by_name['chart_model'].message_type = _CHARTMODELARCHIVE
_CHARTINFOARCHIVE.fields_by_name['style'].message_type = TSPMessages__pb2._REFERENCE
_CHARTINFOARCHIVE.fields_by_name['chart_type'].enum_type = TSCHArchives__Common__pb2._CHARTTYPE
_CHARTINFOARCHIVE.fields_by_name['legend_model'].message_type = _LEGENDMODELARCHIVE
_CHARTINFOARCHIVE.fields_by_name['inner_chart_frame'].message_type = TSCHArchives__Common__pb2._RECTARCHIVE
_CHARTINFOARCHIVE.fields_by_name['value_axis_styles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTINFOARCHIVE.fields_by_name['category_axis_styles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTINFOARCHIVE.fields_by_name['value_axis_nonstyles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTINFOARCHIVE.fields_by_name['category_axis_nonstyles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTINFOARCHIVE.fields_by_name['series_theme_styles'].message_type = TSPMessages__pb2._REFERENCE
_CHARTINFOARCHIVE.fields_by_name['series_private_styles'].message_type = TSPMessages__pb2._SPARSEREFERENCEARRAY
_CHARTINFOARCHIVE.fields_by_name['series_non_styles'].message_type = TSPMessages__pb2._SPARSEREFERENCEARRAY
_CHARTINFOARCHIVE.fields_by_name['non_style'].message_type = TSPMessages__pb2._REFERENCE
_CHARTINFOARCHIVE.fields_by_name['mediator'].message_type = TSPMessages__pb2._REFERENCE
_CHARTINFOARCHIVE.fields_by_name['cde_preview_origin'].message_type = TSPMessages__pb2._POINT
_CHARTINFOARCHIVE.fields_by_name['chart_style_preset'].message_type = TSPMessages__pb2._REFERENCE
_CHARTINFOARCHIVE.fields_by_name['paragraph_styles'].message_type = TSPMessages__pb2._REFERENCE
_LEGENDMODELARCHIVE.fields_by_name['info'].message_type = TSPMessages__pb2._REFERENCE
_LEGENDMODELARCHIVE.fields_by_name['frame'].message_type = TSCHArchives__Common__pb2._RECTARCHIVE
_LEGENDMODELARCHIVE.fields_by_name['style'].message_type = TSPMessages__pb2._REFERENCE
_LEGENDMODELARCHIVE.fields_by_name['non_style'].message_type = TSPMessages__pb2._REFERENCE
_CHARTMODELARCHIVE.fields_by_name['info'].message_type = TSPMessages__pb2._REFERENCE
_CHARTMODELARCHIVE.fields_by_name['grid'].message_type = TSPMessages__pb2._REFERENCE
_CHARTMODELARCHIVE.fields_by_name['inline_grid'].message_type = _CHARTGRIDARCHIVE
_CHARTGRIDARCHIVE_VALUEROW.containing_type = _CHARTGRIDARCHIVE
_CHARTGRIDARCHIVE.fields_by_name['value_row'].message_type = _CHARTGRIDARCHIVE_VALUEROW
_CHARTSNUMBERFORMATARCHIVE.fields_by_name['value_type'].enum_type = TSCHArchives__Common__pb2._NUMBERVALUETYPE
_CHARTSNUMBERFORMATARCHIVE.fields_by_name['negative_style'].enum_type = TSCHArchives__Common__pb2._NEGATIVENUMBERSTYLE
_CHARTSNUMBERFORMATARCHIVE.fields_by_name['fraction_accuracy'].enum_type = TSCHArchives__Common__pb2._FRACTIONACCURACY
_CHARTSNUMBERFORMATARCHIVE.fields_by_name['interstitial_string_insertion_indexes'].message_type = TSPMessages__pb2._INDEXSET
_CHARTSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfodefaultbackgroundfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfodefaultbackgroundstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfodefaultgridbackgroundfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfodefaultborderstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfodefaulttitlecolor'].message_type = TSPMessages__pb2._COLOR
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfodefaultbordershadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfodefaultdeprecatedtrendlineequationshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfodefaultdeprecatedtrendlinersquaredshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfobardeprecated3dshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfocolumndeprecated3dshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfolinedeprecated3dshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfoareadeprecated3dshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfopiedeprecated3dshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfodefault3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfocolumn3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfobar3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfoline3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfoarea3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTSTYLEARCHIVE.fields_by_name['tschchartinfopie3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfodefault3drotation'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfodefault3dscale'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfocolumn3dscale'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfobar3dscale'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfoline3dscale'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfoarea3dscale'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfopie3dscale'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfodefault3dviewport'].message_type = TSCH3DArchives__pb2._CHART3DVECTORARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfodefaultdeprecated3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfocolumndeprecated3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfobardeprecated3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfolinedeprecated3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfoareadeprecated3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_CHARTNONSTYLEARCHIVE.fields_by_name['tschchartinfopiedeprecated3dlightingpackage'].message_type = TSCH3DArchives__pb2._CHART3DLIGHTINGPACKAGEARCHIVE
_LEGENDSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_LEGENDSTYLEARCHIVE.fields_by_name['tschlegendmodeldefaultfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_LEGENDSTYLEARCHIVE.fields_by_name['tschlegendmodeldefaultstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_LEGENDSTYLEARCHIVE.fields_by_name['tschlegendmodeldefaultshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_LEGENDNONSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxisvaluemajorgridlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxisvalueminorgridlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxisvaluemajorgridlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxisvalueminorgridlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxiscategorymajorgridlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxiscategoryminorgridlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxiscategorymajorgridlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxiscategoryminorgridlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxisvalue3dgridlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISSTYLEARCHIVE.fields_by_name['tschchartaxiscategory3dgridlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTAXISNONSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTAXISNONSTYLEARCHIVE.fields_by_name['tschchartaxisdefaultusermin'].message_type = TSCHArchives__Common__pb2._CHARTSNSNUMBERDOUBLEARCHIVE
_CHARTAXISNONSTYLEARCHIVE.fields_by_name['tschchartaxisdefaultusermax'].message_type = TSCHArchives__Common__pb2._CHARTSNSNUMBERDOUBLEARCHIVE
_CHARTAXISNONSTYLEARCHIVE.fields_by_name['tschchartaxisdefaultnumberformat'].message_type = _CHARTSNUMBERFORMATARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesbarfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesbarstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartserieslinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartserieslinesymbolfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartserieslinesymbolstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesareafill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesareastroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesareasymbolfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesareasymbolstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriespiefill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriespiestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesscatterstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesscattersymbolfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesscattersymbolstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaultfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriescolumnfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriespieshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesbarshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesareashadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesscattershadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedareashadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedcolumnshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartserieslineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaultshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesbubblesymbolfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesbubblestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesbubblesymbolstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesbubbleshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dbarshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dcolumnshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dareashadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dpieshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedcolumnfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedareafill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedcolumnstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedareastroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedlinesymbolfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedareasymbolfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedlinesymbolstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesmixedareasymbolstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulttrendlinestroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulttrendlineshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarshadow'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarstroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarstrokescatterx'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarlineend'].message_type = TSDArchives__pb2._LINEENDARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarlineendscatterx'].message_type = TSDArchives__pb2._LINEENDARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesdefaultdeprecated3dfill'].message_type = TSCHArchives__Common__pb2._DEPRECATEDCHART3DFILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesbardeprecated3dfill'].message_type = TSCHArchives__Common__pb2._DEPRECATEDCHART3DFILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriescolumndeprecated3dfill'].message_type = TSCHArchives__Common__pb2._DEPRECATEDCHART3DFILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartserieslinedeprecated3dfill'].message_type = TSCHArchives__Common__pb2._DEPRECATEDCHART3DFILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriesareadeprecated3dfill'].message_type = TSCHArchives__Common__pb2._DEPRECATEDCHART3DFILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseriespiedeprecated3dfill'].message_type = TSCHArchives__Common__pb2._DEPRECATEDCHART3DFILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dbarfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dcolumnfill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dlinefill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dareafill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESSTYLEARCHIVE.fields_by_name['tschchartseries3dpiefill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriesdefaultnumberformat'].message_type = _CHARTSNUMBERFORMATARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriespienumberformat'].message_type = _CHARTSNUMBERFORMATARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriesstackedpercentnumberformat'].message_type = _CHARTSNUMBERFORMATARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarcustompositivedata'].message_type = TSCHArchives__Common__pb2._CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarcustompositivedatascatterx'].message_type = TSCHArchives__Common__pb2._CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarcustomnegativedata'].message_type = TSCHArchives__Common__pb2._CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE
_CHARTSERIESNONSTYLEARCHIVE.fields_by_name['tschchartseriesdefaulterrorbarcustomnegativedatascatterx'].message_type = TSCHArchives__Common__pb2._CHARTSNSARRAYOFNSNUMBERDOUBLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartInfoArchive'] = _CHARTINFOARCHIVE
DESCRIPTOR.message_types_by_name['LegendModelArchive'] = _LEGENDMODELARCHIVE
DESCRIPTOR.message_types_by_name['ChartModelArchive'] = _CHARTMODELARCHIVE
DESCRIPTOR.message_types_by_name['ChartGridArchive'] = _CHARTGRIDARCHIVE
DESCRIPTOR.message_types_by_name['ChartsNumberFormatArchive'] = _CHARTSNUMBERFORMATARCHIVE
DESCRIPTOR.message_types_by_name['ChartStyleArchive'] = _CHARTSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartNonStyleArchive'] = _CHARTNONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['LegendStyleArchive'] = _LEGENDSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['LegendNonStyleArchive'] = _LEGENDNONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartAxisStyleArchive'] = _CHARTAXISSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartAxisNonStyleArchive'] = _CHARTAXISNONSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartSeriesStyleArchive'] = _CHARTSERIESSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['ChartSeriesNonStyleArchive'] = _CHARTSERIESNONSTYLEARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ChartInfoArchive = _reflection.GeneratedProtocolMessageType('ChartInfoArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTINFOARCHIVE,
  __module__ = 'TSCHPreUFFArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.PreUFF.ChartInfoArchive)
  ))
_sym_db.RegisterMessage(ChartInfoArchive)

LegendModelArchive = _reflection.GeneratedProtocolMessageType('LegendModelArchive', (_message.Message,), dict(
  DESCRIPTOR = _LEGENDMODELARCHIVE,
  __module__ = 'TSCHPreUFFArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.PreUFF.LegendModelArchive)
  ))
_sym_db.RegisterMessage(LegendModelArchive)

ChartModelArchive = _reflection.GeneratedProtocolMessageType('ChartModelArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTMODELARCHIVE,
  __module__ = 'TSCHPreUFFArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.PreUFF.ChartModelArchive)
  ))
_sym_db.RegisterMessage(ChartModelArchive)

ChartGridArchive = _reflection.GeneratedProtocolMessageType('ChartGridArchive', (_message.Message,), dict(

  ValueRow = _reflection.GeneratedProtocolMessageType('ValueRow', (_message.Message,), dict(
    DESCRIPTOR = _CHARTGRIDARCHIVE_VALUEROW,
    __module__ = 'TSCHPreUFFArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCH.PreUFF.ChartGridArchive.ValueRow)
    ))
  ,
  DESCRIPTOR = _CHARTGRIDARCHIVE,
  __module__ = 'TSCHPreUFFArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.PreUFF.ChartGridArchive)
  ))
_sym_db.RegisterMessage(ChartGridArchive)
_sym_db.RegisterMessage(ChartGridArchive.ValueRow)

ChartsNumberFormatArchive = _reflection.GeneratedProtocolMessageType('ChartsNumberFormatArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSNUMBERFORMATARCHIVE,
  __module__ = 'TSCHPreUFFArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.PreUFF.ChartsNumberFormatArchive)
  ))
_sym_db.RegisterMessage(ChartsNumberFormatArchive)

ChartStyleArchive = _reflection.GeneratedProtocolMessageType('ChartStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSTYLEARCHIVE,
  __module__ = 'TSCHPreUFFArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.PreUFF.ChartStyleArchive)
  ))
_sym_db.RegisterMessage(ChartStyleArchive)

ChartNonStyleArchive = _reflection.GeneratedProtocolMessageType('ChartNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTNONSTYLEARCHIVE,
  __module__ = 'TSCHPreUFFArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.PreUFF.ChartNonStyleArchive)
  ))
_sym_db.RegisterMessage(ChartNonStyleArchive)

LegendStyleArchive = _reflection.GeneratedProtocolMessageType('LegendStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _LEGENDSTYLEARCHIVE,
  __module__ = 'TSCHPreUFFArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.PreUFF.LegendStyleArchive)
  ))
_sym_db.RegisterMessage(LegendStyleArchive)

LegendNonStyleArchive = _reflection.GeneratedProtocolMessageType('LegendNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _LEGENDNONSTYLEARCHIVE,
  __module__ = 'TSCHPreUFFArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.PreUFF.LegendNonStyleArchive)
  ))
_sym_db.RegisterMessage(LegendNonStyleArchive)

ChartAxisStyleArchive = _reflection.GeneratedProtocolMessageType('ChartAxisStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTAXISSTYLEARCHIVE,
  __module__ = 'TSCHPreUFFArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.PreUFF.ChartAxisStyleArchive)
  ))
_sym_db.RegisterMessage(ChartAxisStyleArchive)

ChartAxisNonStyleArchive = _reflection.GeneratedProtocolMessageType('ChartAxisNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTAXISNONSTYLEARCHIVE,
  __module__ = 'TSCHPreUFFArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.PreUFF.ChartAxisNonStyleArchive)
  ))
_sym_db.RegisterMessage(ChartAxisNonStyleArchive)

ChartSeriesStyleArchive = _reflection.GeneratedProtocolMessageType('ChartSeriesStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSERIESSTYLEARCHIVE,
  __module__ = 'TSCHPreUFFArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.PreUFF.ChartSeriesStyleArchive)
  ))
_sym_db.RegisterMessage(ChartSeriesStyleArchive)

ChartSeriesNonStyleArchive = _reflection.GeneratedProtocolMessageType('ChartSeriesNonStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSERIESNONSTYLEARCHIVE,
  __module__ = 'TSCHPreUFFArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.PreUFF.ChartSeriesNonStyleArchive)
  ))
_sym_db.RegisterMessage(ChartSeriesNonStyleArchive)


# @@protoc_insertion_point(module_scope)
